Sources
=======
Images are taken from `publicdomainpictures.net
<http://www.publicdomainpictures.net/top-images.php>`_. All rights belong
to their respective authors.

License
=======
`Public domain <https://wiki.creativecommons.org/wiki/Public_domain>`_.
When a work is in the public domain, it is free for use by anyone for any
purpose without restriction under copyright law. Public domain is the purest
form of open/free, since no one owns or controls the material in any way.

Authors
=======
`Petr Kratochvil <http://www.publicdomainpictures.net/browse-author.php?a=1>`_
------------------------------------------------------------------------------
- http://www.publicdomainpictures.net/view-image.php?image=2666&picture=tree-in-field
- http://www.publicdomainpictures.net/view-image.php?image=3425&picture=forest-fruit
- http://www.publicdomainpictures.net/view-image.php?image=21750&picture=tropical-paradise
- http://www.publicdomainpictures.net/view-image.php?image=11696&picture=zebra-texture
- http://www.publicdomainpictures.net/view-image.php?image=1733&picture=colorful-pencils
- http://www.publicdomainpictures.net/view-image.php?image=8250&picture=tower-bridge-at-night
- http://www.publicdomainpictures.net/view-image.php?image=1476&picture=cup-of-coffee
- http://www.publicdomainpictures.net/view-image.php?image=4433&picture=sand-heart-and-ocean
- http://www.publicdomainpictures.net/view-image.php?image=5036&picture=ski-resort-with-mountains
- http://www.publicdomainpictures.net/view-image.php?image=6751&picture=tulips-with-blue-sky
- http://www.publicdomainpictures.net/view-image.php?image=7865&picture=big-ben-at-night
- http://www.publicdomainpictures.net/view-image.php?image=557&picture=compact-discs
- http://www.publicdomainpictures.net/view-image.php?image=3430&picture=blueberry-background
- http://www.publicdomainpictures.net/view-image.php?image=12451&picture=fish-underwater
- http://www.publicdomainpictures.net/view-image.php?image=12452&picture=sawfish

`Vera Kratochvil <http://www.publicdomainpictures.net/browse-author.php?a=87>`_
-------------------------------------------------------------------------------
- http://www.publicdomainpictures.net/view-image.php?image=6484&picture=tulip-fields
- http://www.publicdomainpictures.net/view-image.php?image=11111&picture=lions-standing
- http://www.publicdomainpictures.net/view-image.php?image=10723&picture=police-helicopter
- http://www.publicdomainpictures.net/view-image.php?image=5791&picture=three-wind-turbines
- http://www.publicdomainpictures.net/view-image.php?image=8050&picture=westminster-abbey-architecture
- http://www.publicdomainpictures.net/view-image.php?image=12455&picture=jellyfish-background

`Larisa Koshkina <http://www.publicdomainpictures.net/browse-author.php?a=17947>`_
----------------------------------------------------------------------------------
- http://www.publicdomainpictures.net/view-image.php?image=17193&picture=straw-in-the-field
- http://www.publicdomainpictures.net/view-image.php?image=27877&picture=evening-landscape

`Bobby Mikul <http://www.publicdomainpictures.net/browse-author.php?a=2185>`_
-----------------------------------------------------------------------------
- http://www.publicdomainpictures.net/view-image.php?image=16166&picture=empire-state-building

`George Hodan <http://www.publicdomainpictures.net/browse-author.php?a=8245>`_
------------------------------------------------------------------------------
- http://www.publicdomainpictures.net/view-image.php?image=18943&picture=glass-tunnel

`Karen Arnold <http://www.publicdomainpictures.net/browse-author.php?a=32495>`_
-------------------------------------------------------------------------------
- http://www.publicdomainpictures.net/view-image.php?image=76275&picture=kittens-amp-puppy-vintage-photo
- http://www.publicdomainpictures.net/view-image.php?image=76227&picture=cat-dressed-vintage-photo
- http://www.publicdomainpictures.net/view-image.php?image=76231&picture=cute-kitten-vintage-photo
